<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es">
<context>
    <name>AppItemMenu</name>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="34"/>
        <source>Open</source>
        <translation>Abrir</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="46"/>
        <source>Pin to Top</source>
        <translation>Anclar arriba</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="55"/>
        <source>Move to Top</source>
        <translation>Mover al inicio</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="65"/>
        <source>Remove from favorites</source>
        <translation>Eliminar de Favoritos</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="65"/>
        <source>Add to favorites</source>
        <translation>Añadir a Favoritos</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="80"/>
        <source>Send to desktop</source>
        <translation>Enviar al escritorio</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="80"/>
        <source>Remove from desktop</source>
        <translation>Quitar del escritorio</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="91"/>
        <source>Remove from dock</source>
        <translation>Desanclar del muelle</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="91"/>
        <source>Send to dock</source>
        <translation>Anclar al muelle</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="103"/>
        <source>Add to startup</source>
        <translation>Añadir al arranque</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="103"/>
        <source>Remove from startup</source>
        <translation>Quitar del arranque</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="111"/>
        <source>Use a proxy</source>
        <translation>Usar un proxy</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="120"/>
        <source>Disable display scaling</source>
        <translation>Desactivar el escalado de la pantalla</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="127"/>
        <source>Uninstall</source>
        <translation>Desinstalar</translation>
    </message>
</context>
<context>
    <name>BottomBar</name>
    <message>
        <location filename="../qml/windowed/BottomBar.qml" line="33"/>
        <source>Power</source>
        <translation>Encender</translation>
    </message>
    <message>
        <location filename="../qml/windowed/BottomBar.qml" line="62"/>
        <source>Search</source>
        <translation>Buscar</translation>
    </message>
    <message>
        <location filename="../qml/windowed/BottomBar.qml" line="109"/>
        <source>Full-screen Mode</source>
        <translation>Modo pantalla completa</translation>
    </message>
</context>
<context>
    <name>DummyAppItemMenu</name>
    <message>
        <location filename="../qml/DummyAppItemMenu.qml" line="27"/>
        <source>Install</source>
        <translation>Instalar</translation>
    </message>
    <message>
        <location filename="../qml/DummyAppItemMenu.qml" line="34"/>
        <source>Remove</source>
        <translation>Eliminar</translation>
    </message>
</context>
<context>
    <name>FrequentlyUsedView</name>
    <message>
        <location filename="../qml/windowed/FrequentlyUsedView.qml" line="36"/>
        <source>Frequently Used</source>
        <translation>Uso frecuente</translation>
    </message>
</context>
<context>
    <name>FullscreenFrame</name>
    <message>
        <location filename="../qml/FullscreenFrame.qml" line="254"/>
        <source>Window Mode</source>
        <translation>Modo ventana</translation>
    </message>
</context>
<context>
    <name>LauncherController</name>
    <message>
        <location filename="../launchercontroller.cpp" line="21"/>
        <source>Show launcher (hidden by default)</source>
        <translation>Mostrar el lanzador (oculto por defecto)</translation>
    </message>
    <message>
        <location filename="../launchercontroller.cpp" line="22"/>
        <source>Toggle launcher visibility</source>
        <translation>Alternar la visibilidad del lanzador</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <location filename="../qml/Main.qml" line="22"/>
        <source>Internet</source>
        <translation>Internet</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="24"/>
        <source>Chat</source>
        <translation>Mensajería</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="26"/>
        <source>Music</source>
        <translation>Música</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="28"/>
        <source>Video</source>
        <translation>Vídeo</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="30"/>
        <source>Graphics</source>
        <translation>Gráficos</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="32"/>
        <source>Games</source>
        <translation>Juegos</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="34"/>
        <source>Office</source>
        <translation>Ofimática</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="36"/>
        <source>Reading</source>
        <translation>Lectura</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="38"/>
        <source>Development</source>
        <translation>Desarrollo</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="40"/>
        <source>System</source>
        <translation>Sistema</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="42"/>
        <source>Others</source>
        <translation>Otros</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="400"/>
        <source>Are you sure you want to uninstall &quot;%1&quot;?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to uninstall %1?</source>
        <translation type="vanished">¿Seguro que desea desinstalar %1?</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="412"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="426"/>
        <source>Confirm</source>
        <translation>Confirmar</translation>
    </message>
</context>
<context>
    <name>RecentlyInstalledView</name>
    <message>
        <location filename="../qml/windowed/RecentlyInstalledView.qml" line="34"/>
        <source>Recently Installed</source>
        <translation>Instalado recientemente</translation>
    </message>
</context>
<context>
    <name>SearchResultView</name>
    <message>
        <location filename="../qml/windowed/SearchResultView.qml" line="37"/>
        <source>All Apps</source>
        <translation>Todas las aplicaciones</translation>
    </message>
    <message>
        <location filename="../qml/windowed/SearchResultView.qml" line="102"/>
        <location filename="../qml/FullscreenFrame.qml" line="557"/>
        <source>No search results</source>
        <translation>No hay resultados</translation>
    </message>
</context>
<context>
    <name>SideBar</name>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="40"/>
        <source>Free sorting</source>
        <translation>Ordenar libremente</translation>
    </message>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="54"/>
        <source>Sort by category</source>
        <translation>Ordenar por categoría</translation>
    </message>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="66"/>
        <source>Sort by name</source>
        <translation>Ordenar por nombre</translation>
    </message>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="90"/>
        <source>Sorting Mode</source>
        <translation>Modo clasificación</translation>
    </message>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="145"/>
        <source>Computer</source>
        <translation>Ordenador</translation>
    </message>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="156"/>
        <source>Pictures</source>
        <translation>Imágenes</translation>
    </message>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="167"/>
        <source>Documents</source>
        <translation>Documentos</translation>
    </message>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="178"/>
        <source>Desktop</source>
        <translation>Escritorio</translation>
    </message>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="189"/>
        <source>Control Center</source>
        <translation>Centro de control</translation>
    </message>
</context>
</TS>
